==> swear_provention-0.0.4-py3-none-any.whl: swear_provention/swear_provention.py <==
class Filter():
    def __init__(self):
        
        self.swearlist = """4r5e
5h1t
5hit
a55
anal
anus
ar5e
arrse
arse
ass
ass-fucker
asses
assfucker
assfukka
asshole
assholes
asswhole
a_s_s
b!tch
b00bs
b17ch
b1tch
ballbag
balls
ballsack
bastard
beastial
beastiality
bellend
bestial
bestiality
bi+ch
biatch
bitch
bitcher
bitchers
bitches
bitchin
bitching
bloody
blow job
blowjob
blowjobs
boiolas
bollock
bollok
boner
boob
boobs
booobs
boooobs
booooobs
booooooobs
breasts
buceta
bugger
bum
bunny fucker
butt
butthole
buttmunch
buttplug
c0ck
c0cksucker
carpet muncher
cawk
chink
cipa
cl1t
clit
clitoris
clits
cnut
cock
cock-sucker
cockface
cockhead
cockmunch
cockmuncher
cocks
cocksuck 
cocksucked 
cocksucker
cocksucking
cocksucks 
cocksuka
cocksukka
cok
cokmuncher
coksucka
coon
cox
crap
cum
cummer
cumming
cums
cumshot
cunilingus
cunillingus
cunnilingus
cunt
cuntlick 
cuntlicker 
cuntlicking 
cunts
cyalis
cyberfuc
cyberfuck 
cyberfucked 
cyberfucker
cyberfuckers
cyberfucking 
d1ck
damn
dick
dickhead
dildo
dildos
dink
dinks
dirsa
dlck
dog-fucker
doggin
dogging
donkeyribber
doosh
duche
dyke
ejaculate
ejaculated
ejaculates 
ejaculating 
ejaculatings
ejaculation
ejakulate
f u c k
f u c k e r
f4nny
fag
fagging
faggitt
faggot
faggs
fagot
fagots
fags
fanny
fannyflaps
fannyfucker
fanyy
fatass
fcuk
fcuker
fcuking
feck
fecker
felching
fellate
fellatio
fingerfuck 
fingerfucked 
fingerfucker 
fingerfuckers
fingerfucking 
fingerfucks 
fistfuck
fistfucked 
fistfucker 
fistfuckers 
fistfucking 
fistfuckings 
fistfucks 
flange
fook
fooker
fuck
fucka
fucked
fucker
fuckers
fuckhead
fuckheads
fuckin
fucking
fuckings
fuckingshitmotherfucker
fuckme 
fucks
fuckwhit
fuckwit
fudge packer
fudgepacker
fuk
fuker
fukker
fukkin
fuks
fukwhit
fukwit
fux
fux0r
f_u_c_k
gangbang
gangbanged 
gangbangs 
gaylord
gaysex
goatse
God
god-dam
god-damned
goddamn
goddamned
hardcoresex 
hell
heshe
hoar
hoare
hoer
homo
hore
horniest
horny
hotsex
jack-off 
jackoff
jap
jerk-off 
jism
jiz 
jizm 
jizz
kawk
knob
knobead
knobed
knobend
knobhead
knobjocky
knobjokey
kock
kondum
kondums
kum
kummer
kumming
kums
kunilingus
l3i+ch
l3itch
labia
lmfao
lust
lusting
m0f0
m0fo
m45terbate
ma5terb8
ma5terbate
masochist
master-bate
masterb8
masterbat*
masterbat3
masterbate
masterbation
masterbations
masturbate
mo-fo
mof0
mofo
mothafuck
mothafucka
mothafuckas
mothafuckaz
mothafucked 
mothafucker
mothafuckers
mothafuckin
mothafucking 
mothafuckings
mothafucks
mother fucker
motherfuck
motherfucked
motherfucker
motherfuckers
motherfuckin
motherfucking
motherfuckings
motherfuckka
motherfucks
muff
mutha
muthafecker
muthafuckker
muther
mutherfucker
n1gga
n1gger
nazi
nigg3r
nigg4h
nigga
niggah
niggas
niggaz
nigger
niggers 
nob
nob jokey
nobhead
nobjocky
nobjokey
numbnuts
nutsack
orgasim 
orgasims 
orgasm
orgasms 
p0rn
pawn
pecker
penis
penisfucker
phonesex
phuck
phuk
phuked
phuking
phukked
phukking
phuks
phuq
pigfucker
pimpis
piss
pissed
pisser
pissers
pisses 
pissflaps
pissin 
pissing
pissoff 
poop
porn
porno
pornography
pornos
prick
pricks 
pron
pube
pusse
pussi
pussies
pussy
pussys 
rectum
retard
rimjaw
rimming
s hit
s.o.b.
sadist
schlong
screwing
scroat
scrote
scrotum
semen
sex
sh!+
sh!t
sh1t
shag
shagger
shaggin
shagging
shemale
shi+
shit
shitdick
shite
shited
shitey
shitfuck
shitfull
shithead
shiting
shitings
shits
shitted
shitter
shitters 
shitting
shittings
shitty 
skank
slut
sluts
smegma
smut
snatch
son-of-a-bitch
spac
spunk
s_h_i_t
t1tt1e5
t1tties
teets
teez
testical
testicle
tit
titfuck
tits
titt
tittie5
tittiefucker
titties
tittyfuck
tittywank
titwank
tosser
turd
tw4t
twat
twathead
twatty
twunt
twunter
v14gra
v1gra
vagina
viagra
vulva
w00se
wang
wank
wanker
wanky
whoar
whore
willies
willy
xrated
xxx
2 girls 1 cup
4r5e
anal
anus
areole
arian
arrse
arse
arsehole
aryan
aSanchez
ass
testr
ass-fucker
assbang
assbanged
asses
assfuck
assfucker
assfukka
asshole
assmunch
asswhole
auto erotic
autoerotic
ballsack
bastard
bdsm
beastial
beastiality
bellend
bestial
bestiality
bimbo
bimbos
bitch
bitches
bitchin
bitching
blow job
blowjob
blowjobs
blue waffle
bondage
boner
boob
boobs
booobs
boooobs
booooobs
booooooobs
booty call
breasts
brown shower
brown showers
buceta
bukake
bukkake
bull shit
bullshit
busty
butthole
carpet muncher
cawk
chink
cipa
clit
clitoris
clits
cnut
cock
cockface
cockhead
cockmunch
cockmuncher
cocks
cocksuck
cocksucked
cocksucker
cocksucking
cocksucks
cokmuncher
coon
cow girl
cow girls
cowgirl
cowgirls
crap
crotch
cum
cuming
cummer
cumming
cums
cumshot
cunilingus
cunillingus
cunnilingus
cunt
cuntlicker
cuntlicking
cunts
damn
deep throat
deepthroat
dick
dickhead
dildo
dildos
dink
dinks
dlck
dog style
dog-fucker
doggie style
doggie-style
doggiestyle
doggin
dogging
doggy style
doggy-style
doggystyle
dong
donkeyribber
doofus
doosh
dopey
douch3
douche
douchebag
douchebags
douchey
drunk
duche
dumass
dumbass
dumbasses
dummy
dyke
dykes
eatadick
eathairpie
ejaculate
ejaculated
ejaculates
ejaculating
ejaculatings
ejaculation
ejakulate
enlargement
erect
erection
erotic
erotism
essohbee
extacy
extasy
f_u_c_k
f-u-c-k
f.u.c.k
f4nny
facial
fack
fag
fagg
fagged
fagging
faggit
faggitt
faggot
faggs
fagot
fagots
fags
faig
faigt
fanny
fannybandit
fannyflaps
fannyfucker
fanyy
fart
fartknocker
fat
fatass
fcuk
fcuker
fcuking
feck
fecker
felch
felcher
felching
fellate
fellatio
feltch
feltcher
femdom
fingerfuck
fingerfucked
fingerfucker
fingerfuckers
fingerfucking
fingerfucks
fingering
fisted
fistfuck
fistfucked
fistfucker
fistfuckers
fistfucking
fistfuckings
fistfucks
fisting
fisty
flange
flogthelog
floozy
foad
fondle
foobar
fook
fooker
foot job
footjob
foreskin
freex
frigg
frigga
fubar
fuck
fuck-ass
fuck-bitch
fuck-tard
fucka
fuckass
fucked
fucker
fuckers
fuckface
fuckhead
fuckheads
fuckhole
fuckin
fucking
fuckings
fuckingshitmotherfucker
fuckme
fuckmeat
fucknugget
fucknut
fuckoff
fuckpuppet
fucks
fucktard
fucktoy
fucktrophy
fuckup
fuckwad
fuckwhit
fuckwit
fuckyomama
fudgepacker
fuk
fuker
fukker
fukkin
fukking
fuks
fukwhit
fukwit
futanari
futanary
fux
fux0r
fvck
fxck
g-spot
gae
gai
gang bang
gang-bang
gangbang
gangbanged
gangbangs
ganja
gassyass
gay
gaylord
gays
gaysex
gey
gfy
ghay
ghey
gigolo
glans
goatse
god
god-dam
god-damned
godamn
godamnit
goddam
goddammit
goddamn
goddamned
gokkun
golden shower
goldenshower
gonad
gonads
gook
gooks
gringo
gspot
gtfo
guido
h0m0
h0mo
hamflap
hand job
handjob
hardcoresex
hardon
he11
hebe
heeb
hell
hemp
hentai
heroin
herp
herpes
herpy
heshe
hitler
hiv
hoar
hoare
hobag
hoer
hom0
homey
homo
homoerotic
homoey
honky
hooch
hookah
hooker
hoor
hootch
hooter
hooters
hore
horniest
horny
hotsex
howtokill
howtomurdep
hump
humped
humping
hussy
hymen
inbred
incest
injun
j3rk0ff
jack off
jack-off
jackass
jackhole
jackoff
jap
japs
jerk
jerk off
jerk-off
jerk0ff
jerked
jerkoff
jism
jiz
jizm
jizz
jizzed
junkie
junky
kawk
kike
kikes
kill
kinbaku
kinky
kinkyJesus
kkk
klan
knob
knobead
knobed
knobend
knobhead
knobjocky
knobjokey
kock
kondum
kondums
kooch
kooches
kootch
kraut
kum
kummer
kumming
kums
kunilingus
kwif
kyke
l3i+ch
l3itch
labia
lech
LEN
leper
lesbians
lesbo
lesbos
lez
lezbian
lezbians
lezbo
lezbos
lezzie
lezzies
lezzy
lmao
lmfao
loin
loins
lube
lust
lusting
lusty
m-fucking
m0f0
m0fo
m45terbate
ma5terb8
ma5terbate
mafugly
mams
masochist
massa
master-bate
masterb8
masterbat*
masterbat3
masterbate
masterbating
masterbation
masterbations
masturbate
masturbating
masturbation
maxi
menses
menstruate
menstruation
meth
milf
mo-fo
mof0
mofo
molest
moolie
moron
mothafuck
mothafucka
mothafuckas
mothafuckaz
mothafucked
mothafucker
mothafuckers
mothafuckin
mothafucking
mothafuckings
mothafucks
mother fucker
motherfuck
motherfucka
motherfucked
motherfucker
motherfuckers
motherfuckin
motherfucking
motherfuckings
motherfuckka
motherfucks
mtherfucker
mthrfucker
mthrfucking
muff
muffdiver
muffpuff
murder
mutha
muthafecker
muthafuckaz
muthafucker
muthafuckker
muther
mutherfucker
mutherfucking
muthrfucking
n1g
n1gg
n1gga
n1gger
nad
nads
naked
napalm
nappy
nazi
nazism
needthedick
negro
nig
nigg
nigg3r
nigg4h
nigga
niggah
niggas
niggaz
nigger
niggers
niggle
niglet
nimrod
ninny
nipple
nipples
nob
nob jokey
nobhead
nobjocky
nobjokey
nooky
nude
nudes
numbnuts
nutbutter
nutsack
nympho
omg
opiate
opium
oral
orally
organ
orgasim
orgasims
orgasm
orgasmic
orgasms
orgies
orgy
ovary
ovum
ovums
p.u.s.s.y.
p0rn
paddy
paki
pantie
panties
panty
pastie
pasty
pawn
pcp
pecker
pedo
pedophile
pedophilia
pedophiliac
pee
peepee
penetrate
penetration
penial
penile
penis
penisfucker
perversion
peyote
phalli
phallic
phonesex
phuck
phuk
phuked
phuking
phukked
phukking
phuks
phuq
pigfucker
pillowbiter
pimp
pimpis
pinko
piss
piss-off
pissed
pisser
pissers
pisses
pissflaps
pissin
pissing
pissoff
playboy
pms
polack
pollock
poon
poontang
poop
porn
porno
pornography
pornos
pot
potty
prick
pricks
prig
pron
prostitute
prude
pube
pubic
pubis
punkass
punky
puss
pusse
pussi
pussies
pussy
pussyfart
pussypalace
pussypounder
pussys
puto
queaf
queef
queer
queero
queers
quicky
quim
r-tard
racy
rape
raped
raper
raping
rapist
raunch
rectal
rectum
rectus
reefer
reetard
reich
retard
retarded
revue
rimjaw
rimjob
rimming
ritard
rtard
rum
rump
rumprammer
ruski
s_h_i_t
s-h-1-t
s-h-i-t
s-o-b
s.h.i.t.
s.o.b.
s0b
sadism
sadist
sandbar
sausagequeen
scag
scantily
schizo
schlong
screw
screwed
screwing
scroat
scrog
scrot
scrote
scrotum
scrud
scum
seaman
seamen
seduce
semen
sex
sexual
sh!+
sh!t
sh1t
shag
shagger
shaggin
shagging
shamedame
she male
shemale
shi+
shibari
shibary
shit
shitdick
shite
shiteater
shited
shitey
shitface
shitfuck
shitfucker
shitfull
shithead
shithole
shithouse
shiting
shitings
shits
shitt
shitted
shitter
shitters
shitting
shittings
shitty
shiz
shota
sissy
skag
skank
slave
sleaze
sleazy
slope
slut
slutbucket
slutdumper
slutkiss
sluts
smegma
smut
smutty
snatch
sniper
snuff
sodom
son-of-a-bitch
souse
soused
spac
sperm
spic
spick
spik
spiks
spooge
spunk
steamy
stfu
stiffy
stoned
strip
strip club
stripclub
stroke
stupid
suck
sucked
sucking
sumofabiatch
t1t
t1tt1e5
t1tties
tampon
tard
tawdry
teabagging
teat
teets
teez
terd
teste
testee
testes
testical
testicle
testis
three some
threesome
throating
thrust
thug
tinkle
tit
titfuck
titi
tits
titt
tittie5
tittiefucker
titties
titty
tittyfuck
tittyfucker
tittywank
titwank
toke
toots
tosser
tramp
transsexual
trashy
tubgirl
turd
tush
tw4t
twat
twathead
twats
twatty
twunt
twunter
ugly
undies
unwed
urinal
urine
uterus
uzi
v14gra
v1gra
vag
vagina
valium
viagra
virgin
vixen
vodka
vomit
voyeur
vulgar
vulva
w00se
wad
wang
wank
wanker
wanky
wazoo
wedgie
weed
weenie
weewee
weiner
weirdo
wench
wetback
wh0re
wh0reface
whitey
whiz
whoar
whoralicious
whore
whorealicious
whored
whoreface
whorehopper
whorehouse
whores
whoring
wigger
willies
willy
womb
woody
wop
wtf
x-rated2g1c
xx
xxx
yaoi
yury
"""
        self.swearlist = self.swearlist.split("\n")

        self.grammah = [",",".","?"," ","!","(",")",":",";"]
        
        self.result = []
        self.censor = ""
        self.CHARS_MAPPING = {
                    "a": ("a", "@", "*", "4"),
                    "i": ("i", "*"),
                    "o": ("o", "*", "0", "@"),
                    "u": ("u", "*", "v"),
                    "v": ("v", "*", "u"),
                    "l": ("l", "1", "l", "1"),
                    "e": ("e", "*", "3"),
                    "s": ("s", "$", "5"),
                    "t": ("t", "7")}
    def filter(self,text):
        self.censor = ""
        text = list(text)
        for i in range(len(text)):
            temp = text[i].lower()
            for key,value in self.CHARS_MAPPING.items():
                    if temp in value:
                        
                        temp = key
                        
                        break
            self.censor += temp
        for i in range(len(self.swearlist)):
            length = len(self.swearlist[i])
            censored = ""
            for l in range(length):
                censored += "*"
            for o in range(len(self.censor)- length + 1):
                
                if self.censor[o:length + o] == self.swearlist[i]:
                    
                    text[o:length + o] = censored
        return "".join(text)

test = Filter()

==> swear_provention-0.0.6-py3-none-any.whl: swear_provention/swear_provention.py <==
def  Filter(text):
    
        
        swearlist = """4r5e
5h1t
5hit
a55
anal
anus
ar5e
arrse
arse
ass
ass-fucker
asses
assfucker
assfukka
asshole
assholes
asswhole
a_s_s
b!tch
b00bs
b17ch
b1tch
ballbag
balls
ballsack
bastard
beastial
beastiality
bellend
bestial
bestiality
bi+ch
biatch
bitch
bitcher
bitchers
bitches
bitchin
bitching
bloody
blow job
blowjob
blowjobs
boiolas
bollock
bollok
boner
boob
boobs
booobs
boooobs
booooobs
booooooobs
breasts
buceta
bugger
bum
bunny fucker
butt
butthole
buttmunch
buttplug
c0ck
c0cksucker
carpet muncher
cawk
chink
cipa
cl1t
clit
clitoris
clits
cnut
cock
cock-sucker
cockface
cockhead
cockmunch
cockmuncher
cocks
cocksuck 
cocksucked 
cocksucker
cocksucking
cocksucks 
cocksuka
cocksukka
cok
cokmuncher
coksucka
coon
cox
crap
cum
cummer
cumming
cums
cumshot
cunilingus
cunillingus
cunnilingus
cunt
cuntlick 
cuntlicker 
cuntlicking 
cunts
cyalis
cyberfuc
cyberfuck 
cyberfucked 
cyberfucker
cyberfuckers
cyberfucking 
d1ck
damn
dick
dickhead
dildo
dildos
dink
dinks
dirsa
dlck
dog-fucker
doggin
dogging
donkeyribber
doosh
duche
dyke
ejaculate
ejaculated
ejaculates 
ejaculating 
ejaculatings
ejaculation
ejakulate
f u c k
f u c k e r
f4nny
fag
fagging
faggitt
faggot
faggs
fagot
fagots
fags
fanny
fannyflaps
fannyfucker
fanyy
fatass
fcuk
fcuker
fcuking
feck
fecker
felching
fellate
fellatio
fingerfuck 
fingerfucked 
fingerfucker 
fingerfuckers
fingerfucking 
fingerfucks 
fistfuck
fistfucked 
fistfucker 
fistfuckers 
fistfucking 
fistfuckings 
fistfucks 
flange
fook
fooker
fuck
fucka
fucked
fucker
fuckers
fuckhead
fuckheads
fuckin
fucking
fuckings
fuckingshitmotherfucker
fuckme 
fucks
fuckwhit
fuckwit
fudge packer
fudgepacker
fuk
fuker
fukker
fukkin
fuks
fukwhit
fukwit
fux
fux0r
f_u_c_k
gangbang
gangbanged 
gangbangs 
gaylord
gaysex
goatse
God
god-dam
god-damned
goddamn
goddamned
hardcoresex 
hell
heshe
hoar
hoare
hoer
homo
hore
horniest
horny
hotsex
jack-off 
jackoff
jap
jerk-off 
jism
jiz 
jizm 
jizz
kawk
knob
knobead
knobed
knobend
knobhead
knobjocky
knobjokey
kock
kondum
kondums
kum
kummer
kumming
kums
kunilingus
l3i+ch
l3itch
labia
lmfao
lust
lusting
m0f0
m0fo
m45terbate
ma5terb8
ma5terbate
masochist
master-bate
masterb8
masterbat*
masterbat3
masterbate
masterbation
masterbations
masturbate
mo-fo
mof0
mofo
mothafuck
mothafucka
mothafuckas
mothafuckaz
mothafucked 
mothafucker
mothafuckers
mothafuckin
mothafucking 
mothafuckings
mothafucks
mother fucker
motherfuck
motherfucked
motherfucker
motherfuckers
motherfuckin
motherfucking
motherfuckings
motherfuckka
motherfucks
muff
mutha
muthafecker
muthafuckker
muther
mutherfucker
n1gga
n1gger
nazi
nigg3r
nigg4h
nigga
niggah
niggas
niggaz
nigger
niggers 
nob
nob jokey
nobhead
nobjocky
nobjokey
numbnuts
nutsack
orgasim 
orgasims 
orgasm
orgasms 
p0rn
pawn
pecker
penis
penisfucker
phonesex
phuck
phuk
phuked
phuking
phukked
phukking
phuks
phuq
pigfucker
pimpis
piss
pissed
pisser
pissers
pisses 
pissflaps
pissin 
pissing
pissoff 
poop
porn
porno
pornography
pornos
prick
pricks 
pron
pube
pusse
pussi
pussies
pussy
pussys 
rectum
retard
rimjaw
rimming
s hit
s.o.b.
sadist
schlong
screwing
scroat
scrote
scrotum
semen
sex
sh!+
sh!t
sh1t
shag
shagger
shaggin
shagging
shemale
shi+
shit
shitdick
shite
shited
shitey
shitfuck
shitfull
shithead
shiting
shitings
shits
shitted
shitter
shitters 
shitting
shittings
shitty 
skank
slut
sluts
smegma
smut
snatch
son-of-a-bitch
spac
spunk
s_h_i_t
t1tt1e5
t1tties
teets
teez
testical
testicle
tit
titfuck
tits
titt
tittie5
tittiefucker
titties
tittyfuck
tittywank
titwank
tosser
turd
tw4t
twat
twathead
twatty
twunt
twunter
v14gra
v1gra
vagina
viagra
vulva
w00se
wang
wank
wanker
wanky
whoar
whore
willies
willy
xrated
xxx
2 girls 1 cup
4r5e
anal
anus
areole
arian
arrse
arse
arsehole
aryan
aSanchez
ass
testr
ass-fucker
assbang
assbanged
asses
assfuck
assfucker
assfukka
asshole
assmunch
asswhole
auto erotic
autoerotic
ballsack
bastard
bdsm
beastial
beastiality
bellend
bestial
bestiality
bimbo
bimbos
bitch
bitches
bitchin
bitching
blow job
blowjob
blowjobs
blue waffle
bondage
boner
boob
boobs
booobs
boooobs
booooobs
booooooobs
booty call
breasts
brown shower
brown showers
buceta
bukake
bukkake
bull shit
bullshit
busty
butthole
carpet muncher
cawk
chink
cipa
clit
clitoris
clits
cnut
cock
cockface
cockhead
cockmunch
cockmuncher
cocks
cocksuck
cocksucked
cocksucker
cocksucking
cocksucks
cokmuncher
coon
cow girl
cow girls
cowgirl
cowgirls
crap
crotch
cum
cuming
cummer
cumming
cums
cumshot
cunilingus
cunillingus
cunnilingus
cunt
cuntlicker
cuntlicking
cunts
damn
deep throat
deepthroat
dick
dickhead
dildo
dildos
dink
dinks
dlck
dog style
dog-fucker
doggie style
doggie-style
doggiestyle
doggin
dogging
doggy style
doggy-style
doggystyle
dong
donkeyribber
doofus
doosh
dopey
douch3
douche
douchebag
douchebags
douchey
drunk
duche
dumass
dumbass
dumbasses
dummy
dyke
dykes
eatadick
eathairpie
ejaculate
ejaculated
ejaculates
ejaculating
ejaculatings
ejaculation
ejakulate
enlargement
erect
erection
erotic
erotism
essohbee
extacy
extasy
f_u_c_k
f-u-c-k
f.u.c.k
f4nny
facial
fack
fag
fagg
fagged
fagging
faggit
faggitt
faggot
faggs
fagot
fagots
fags
faig
faigt
fanny
fannybandit
fannyflaps
fannyfucker
fanyy
fart
fartknocker
fat
fatass
fcuk
fcuker
fcuking
feck
fecker
felch
felcher
felching
fellate
fellatio
feltch
feltcher
femdom
fingerfuck
fingerfucked
fingerfucker
fingerfuckers
fingerfucking
fingerfucks
fingering
fisted
fistfuck
fistfucked
fistfucker
fistfuckers
fistfucking
fistfuckings
fistfucks
fisting
fisty
flange
flogthelog
floozy
foad
fondle
foobar
fook
fooker
foot job
footjob
foreskin
freex
frigg
frigga
fubar
fuck
fuck-ass
fuck-bitch
fuck-tard
fucka
fuckass
fucked
fucker
fuckers
fuckface
fuckhead
fuckheads
fuckhole
fuckin
fucking
fuckings
fuckingshitmotherfucker
fuckme
fuckmeat
fucknugget
fucknut
fuckoff
fuckpuppet
fucks
fucktard
fucktoy
fucktrophy
fuckup
fuckwad
fuckwhit
fuckwit
fuckyomama
fudgepacker
fuk
fuker
fukker
fukkin
fukking
fuks
fukwhit
fukwit
futanari
futanary
fux
fux0r
fvck
fxck
g-spot
gae
gai
gang bang
gang-bang
gangbang
gangbanged
gangbangs
ganja
gassyass
gay
gaylord
gays
gaysex
gey
gfy
ghay
ghey
gigolo
glans
goatse
god
god-dam
god-damned
godamn
godamnit
goddam
goddammit
goddamn
goddamned
gokkun
golden shower
goldenshower
gonad
gonads
gook
gooks
gringo
gspot
gtfo
guido
h0m0
h0mo
hamflap
hand job
handjob
hardcoresex
hardon
he11
hebe
heeb
hell
hemp
hentai
heroin
herp
herpes
herpy
heshe
hitler
hiv
hoar
hoare
hobag
hoer
hom0
homey
homo
homoerotic
homoey
honky
hooch
hookah
hooker
hoor
hootch
hooter
hooters
hore
horniest
horny
hotsex
howtokill
howtomurdep
hump
humped
humping
hussy
hymen
inbred
incest
injun
j3rk0ff
jack off
jack-off
jackass
jackhole
jackoff
jap
japs
jerk
jerk off
jerk-off
jerk0ff
jerked
jerkoff
jism
jiz
jizm
jizz
jizzed
junkie
junky
kawk
kike
kikes
kill
kinbaku
kinky
kinkyJesus
kkk
klan
knob
knobead
knobed
knobend
knobhead
knobjocky
knobjokey
kock
kondum
kondums
kooch
kooches
kootch
kraut
kum
kummer
kumming
kums
kunilingus
kwif
kyke
l3i+ch
l3itch
labia
lech
LEN
leper
lesbians
lesbo
lesbos
lez
lezbian
lezbians
lezbo
lezbos
lezzie
lezzies
lezzy
lmao
lmfao
loin
loins
lube
lust
lusting
lusty
m-fucking
m0f0
m0fo
m45terbate
ma5terb8
ma5terbate
mafugly
mams
masochist
massa
master-bate
masterb8
masterbat*
masterbat3
masterbate
masterbating
masterbation
masterbations
masturbate
masturbating
masturbation
maxi
menses
menstruate
menstruation
meth
milf
mo-fo
mof0
mofo
molest
moolie
moron
mothafuck
mothafucka
mothafuckas
mothafuckaz
mothafucked
mothafucker
mothafuckers
mothafuckin
mothafucking
mothafuckings
mothafucks
mother fucker
motherfuck
motherfucka
motherfucked
motherfucker
motherfuckers
motherfuckin
motherfucking
motherfuckings
motherfuckka
motherfucks
mtherfucker
mthrfucker
mthrfucking
muff
muffdiver
muffpuff
murder
mutha
muthafecker
muthafuckaz
muthafucker
muthafuckker
muther
mutherfucker
mutherfucking
muthrfucking
n1g
n1gg
n1gga
n1gger
nad
nads
naked
napalm
nappy
nazi
nazism
needthedick
negro
nig
nigg
nigg3r
nigg4h
nigga
niggah
niggas
niggaz
nigger
niggers
niggle
niglet
nimrod
ninny
nipple
nipples
nob
nob jokey
nobhead
nobjocky
nobjokey
nooky
nude
nudes
numbnuts
nutbutter
nutsack
nympho
omg
opiate
opium
oral
orally
organ
orgasim
orgasims
orgasm
orgasmic
orgasms
orgies
orgy
ovary
ovum
ovums
p.u.s.s.y.
p0rn
paddy
paki
pantie
panties
panty
pastie
pasty
pawn
pcp
pecker
pedo
pedophile
pedophilia
pedophiliac
pee
peepee
penetrate
penetration
penial
penile
penis
penisfucker
perversion
peyote
phalli
phallic
phonesex
phuck
phuk
phuked
phuking
phukked
phukking
phuks
phuq
pigfucker
pillowbiter
pimp
pimpis
pinko
piss
piss-off
pissed
pisser
pissers
pisses
pissflaps
pissin
pissing
pissoff
playboy
pms
polack
pollock
poon
poontang
poop
porn
porno
pornography
pornos
pot
potty
prick
pricks
prig
pron
prostitute
prude
pube
pubic
pubis
punkass
punky
puss
pusse
pussi
pussies
pussy
pussyfart
pussypalace
pussypounder
pussys
puto
queaf
queef
queer
queero
queers
quicky
quim
r-tard
racy
rape
raped
raper
raping
rapist
raunch
rectal
rectum
rectus
reefer
reetard
reich
retard
retarded
revue
rimjaw
rimjob
rimming
ritard
rtard
rum
rump
rumprammer
ruski
s_h_i_t
s-h-1-t
s-h-i-t
s-o-b
s.h.i.t.
s.o.b.
s0b
sadism
sadist
sandbar
sausagequeen
scag
scantily
schizo
schlong
screw
screwed
screwing
scroat
scrog
scrot
scrote
scrotum
scrud
scum
seaman
seamen
seduce
semen
sex
sexual
sh!+
sh!t
sh1t
shag
shagger
shaggin
shagging
shamedame
she male
shemale
shi+
shibari
shibary
shit
shitdick
shite
shiteater
shited
shitey
shitface
shitfuck
shitfucker
shitfull
shithead
shithole
shithouse
shiting
shitings
shits
shitt
shitted
shitter
shitters
shitting
shittings
shitty
shiz
shota
sissy
skag
skank
slave
sleaze
sleazy
slope
slut
slutbucket
slutdumper
slutkiss
sluts
smegma
smut
smutty
snatch
sniper
snuff
sodom
son-of-a-bitch
souse
soused
spac
sperm
spic
spick
spik
spiks
spooge
spunk
steamy
stfu
stiffy
stoned
strip
strip club
stripclub
stroke
stupid
suck
sucked
sucking
sumofabiatch
t1t
t1tt1e5
t1tties
tampon
tard
tawdry
teabagging
teat
teets
teez
terd
teste
testee
testes
testical
testicle
testis
three some
threesome
throating
thrust
thug
tinkle
tit
titfuck
titi
tits
titt
tittie5
tittiefucker
titties
titty
tittyfuck
tittyfucker
tittywank
titwank
toke
toots
tosser
tramp
transsexual
trashy
tubgirl
turd
tush
tw4t
twat
twathead
twats
twatty
twunt
twunter
ugly
undies
unwed
urinal
urine
uterus
uzi
v14gra
v1gra
vag
vagina
valium
viagra
virgin
vixen
vodka
vomit
voyeur
vulgar
vulva
w00se
wad
wang
wank
wanker
wanky
wazoo
wedgie
weed
weenie
weewee
weiner
weirdo
wench
wetback
wh0re
wh0reface
whitey
whiz
whoar
whoralicious
whore
whorealicious
whored
whoreface
whorehopper
whorehouse
whores
whoring
wigger
willies
willy
womb
woody
wop
wtf
x-rated2g1c
xx
xxx
yaoi
yury
"""
        swearlist = swearlist.split("\n")

        grammah = [",",".","?"," ","!","(",")",":",";"]
        
        result = []
        censor = ""
        CHARS_MAPPING = {
                    "a": ("a", "@", "*", "4"),
                    "i": ("i", "*"),
                    "o": ("o", "*", "0", "@"),
                    "u": ("u", "*", "v"),
                    "v": ("v", "*", "u"),
                    "l": ("l", "1", "l", "1"),
                    "e": ("e", "*", "3"),
                    "s": ("s", "$", "5"),
                    "t": ("t", "7")}
    
        censor = ""
        text = list(text)
        for i in range(len(text)):
            temp = text[i].lower()
            for key,value in CHARS_MAPPING.items():
                    if temp in value:
                        
                        temp = key
                        
                        break
            censor += temp
        for i in range(len(swearlist)):
            length = len(swearlist[i])
            censored = ""
            for l in range(length):
                censored += "*"
            for o in range(len(censor)- length + 1):
                
                if censor[o:length + o] == swearlist[i]:
                    
                    text[o:length + o] = censored
        return "".join(text)

test = Filter("shit")
